@@ -382,6 +382,14 @@ Press. B<1990>. ISBN 0-19-853737-9. Ch. 10.3, pp 390-391.
 =head1 HISTORY
 
  $Log: comment.pm,v $
+ Revision 2.100  2003/01/21 23:19:40  abigail
+ The whole world understands RCS/CVS version numbers, that 1.9 is an
+ older version than 1.10. Except CPAN. Curse the idiot(s) who think
+ that version numbers are floats (in which universe do floats have
+ more than one decimal dot?).
+ Everything is bumped to version 2.100 because CPAN couldn't deal
+ with the fact one file had version 1.10.
+
  Revision 1.19  2002/11/06 13:51:34  abigail
  Minor POD changes.
 
