@@ -8,7 +8,7 @@ use Carp;
 
 use vars qw /$VERSION/;
 
-($VERSION) = q $Revision: 1.2 $ =~ /[\d.]+/;
+($VERSION) = q $Revision: 2.100 $ =~ /[\d.]+/;
 
 pattern name    => [qw /lingua palindrome -chars=[A-Za-z]/],
         create  => sub {
@@ -99,6 +99,14 @@ The 4 digit extention (if any).
 =head1 HISTORY
 
  $Log: lingua.pm,v $
+ Revision 2.100  2003/01/21 23:19:40  abigail
+ The whole world understands RCS/CVS version numbers, that 1.9 is an
+ older version than 1.10. Except CPAN. Curse the idiot(s) who think
+ that version numbers are floats (in which universe do floats have
+ more than one decimal dot?).
+ Everything is bumped to version 2.100 because CPAN couldn't deal
+ with the fact one file had version 1.10.
+
  Revision 1.2  2003/01/01 19:11:29  abigail
  Fixed problem with having different palindrome patterns in same program
 
