@@ -59,6 +59,14 @@ This pattern does not capture under C<-keep>.
 =head1 HISTORY
 
  $Log: whitespace.pm,v $
+ Revision 2.100  2003/01/21 23:19:40  abigail
+ The whole world understands RCS/CVS version numbers, that 1.9 is an
+ older version than 1.10. Except CPAN. Curse the idiot(s) who think
+ that version numbers are floats (in which universe do floats have
+ more than one decimal dot?).
+ Everything is bumped to version 2.100 because CPAN couldn't deal
+ with the fact one file had version 1.10.
+
  Revision 1.2  2002/08/27 16:59:39  abigail
  Fix POD
 
